const DIFFICULT_WORDS = [
  'accommodate', 'accordance', 'acquisition', 'ambiguous', 'bureaucracy',
  'characteristic', 'circumstantial', 'coincidence', 'colleague', 'commemorate',
  'commissary', 'commitment', 'committee', 'competitive', 'completely',
  'concurrence', 'conflagration', 'conscientious', 'consistent', 'convenient',
  'correspondence', 'definitely', 'development', 'difference', 'discipline',
  'dissimilar', 'efficient', 'embarrass', 'especially', 'exhilarate',
  'experience', 'fascinating', 'government', 'grandiloquent', 'guarantee',
  'harassment', 'hierarchy', 'humorous', 'hypocrite', 'ignominious',
  'immediate', 'incandescent', 'incredible', 'independent', 'industrial',
  'infinitesimal', 'influential', 'inspiration', 'intelligence', 'maintenance',
  'medieval', 'millennium', 'miniature', 'necessary', 'obstinate',
  'occurrence', 'opportunity', 'parliament', 'perseverance', 'personnel',
  'perspective', 'phenomenon', 'preference', 'prejudice', 'prevalent'
];

let availableWords = [...DIFFICULT_WORDS];
let currentWord = '';
let userInput = '';
let stats = { correct: 0, attempted: 0, skipped: 0 };

const wordDisplay = document.querySelector('.current-word');
const inputDisplay = document.querySelector('.input-display');
const correctCount = document.getElementById('correct-count');
const attemptedCount = document.getElementById('attempted-count');
const successRate = document.getElementById('success-rate');
const skippedCount = document.getElementById('skipped-count');

function selectNewWord() {
  if (availableWords.length === 0) {
    availableWords = [...DIFFICULT_WORDS];
  }
  const index = Math.floor(Math.random() * availableWords.length);
  currentWord = availableWords[index];
  availableWords.splice(index, 1);
  wordDisplay.textContent = currentWord;
  inputDisplay.textContent = '';
  userInput = '';
}

function speakWord(word) {
  const utterance = new SpeechSynthesisUtterance(word);
  const voices = window.speechSynthesis.getVoices();
  const maleVoice = voices.find(voice => 
    voice.name.includes('Male') || 
    voice.name.includes('male') || 
    voice.name.includes('David') ||
    voice.name.includes('James') ||
    voice.name.includes('Daniel')
  );
  if (maleVoice) {
    utterance.voice = maleVoice;
  }
  utterance.rate = 0.9;
  utterance.pitch = 0.8;
  utterance.volume = 1.0;
  window.speechSynthesis.speak(utterance);
}

function updateStats() {
  correctCount.textContent = stats.correct;
  attemptedCount.textContent = stats.attempted;
  skippedCount.textContent = stats.skipped;
  successRate.textContent = `${((stats.correct / (stats.attempted || 1)) * 100).toFixed(1)}%`;
}

document.getElementById('play-button').addEventListener('click', () => {
  speakWord(currentWord);
});

document.getElementById('skip-button').addEventListener('click', () => {
  stats.skipped++;
  selectNewWord();
  updateStats();
});

document.getElementById('hint-button').addEventListener('click', () => {
  inputDisplay.textContent = currentWord;
});

document.getElementById('enter-button').addEventListener('click', () => {
  if (userInput.toLowerCase() === currentWord.toLowerCase()) {
    stats.correct++;
    stats.attempted++;
    alert('Correct!');
    selectNewWord();
  } else {
    stats.attempted++;
    alert('Incorrect, try again!');
  }
  updateStats();
});

document.querySelectorAll('.keyboard button').forEach(button => {
  if (!button.classList.contains('backspace-button')) {
    button.addEventListener('click', () => {
      if (userInput.length < currentWord.length) {
        userInput += button.textContent;
        inputDisplay.textContent = userInput;
      }
    });
  }
});

document.querySelector('.backspace-button').addEventListener('click', () => {
  userInput = userInput.slice(0, -1);
  inputDisplay.textContent = userInput;
});

document.getElementById('reset-button').addEventListener('click', () => {
  availableWords = [...DIFFICULT_WORDS];
  stats = { correct: 0, attempted: 0, skipped: 0 };
  selectNewWord();
  updateStats();
});

// Initialize game
selectNewWord();